import { EventEmitter, Injectable, ɵɵdefineInjectable, Component, ViewEncapsulation, Input, Output, NgModule } from '@angular/core';
import { BehaviorSubject, fromEvent } from 'rxjs';
import { debounceTime, startWith } from 'rxjs/operators';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/services/network-detection.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NetworkDetectionService {
    constructor() {
        this.currentState = {
            hasInternetAccess: false,
            hasNetworkConnection: window.navigator.onLine
        };
        this.stateChangeEventEmitter = new EventEmitter();
        this.resetPlayerSub = new BehaviorSubject(null);
        this.checkNetworkState();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        try {
            this.offlineSubscription.unsubscribe();
            this.onlineSubscription.unsubscribe();
        }
        catch (e) {
        }
    }
    /**
     * @private
     * @return {?}
     */
    checkNetworkState() {
        this.onlineSubscription = fromEvent(window, 'online').subscribe((/**
         * @return {?}
         */
        () => {
            this.currentState.hasNetworkConnection = true;
            this.currentState.hasInternetAccess = true;
            // console.log('online: ', this.currentState);
            this.emitEvent();
        }));
        this.offlineSubscription = fromEvent(window, 'offline').subscribe((/**
         * @return {?}
         */
        () => {
            this.currentState.hasNetworkConnection = false;
            this.currentState.hasInternetAccess = false;
            // console.log('offline: ', this.currentState);
            this.emitEvent();
        }));
    }
    /**
     * @private
     * @return {?}
     */
    emitEvent() {
        this.stateChangeEventEmitter.emit(this.currentState);
    }
    /**
     * Monitor Network & Internet connection status by subscribing to this observer. If you set "reportCurrentState" to "false" then
     * function will not report current status of the connections when initially subscribed.
     * @param {?=} reportCurrentState Report current state when initial subscription. Default is "true"
     * @return {?}
     */
    monitor(reportCurrentState = true) {
        return reportCurrentState ?
            this.stateChangeEventEmitter.pipe(debounceTime(300), startWith(this.currentState))
            :
                this.stateChangeEventEmitter.pipe(debounceTime(300));
    }
    /**
     * @param {?} data
     * @return {?}
     */
    setResetPlayer(data) {
        /** @type {?} */
        let resetTime = data.resetAfter;
        /** @type {?} */
        const lastPlaybackRate = data.lastPlaybackRate;
        this.clearTimer();
        // this.resetPlayerTimer = setTimeout(() => {
        //   this.resetPlayerSub.next(true);
        // }, resetTime);
        this.resetPlayerTimer = setInterval((/**
         * @return {?}
         */
        () => {
            console.log(resetTime);
            resetTime = resetTime - lastPlaybackRate;
            if (resetTime <= 0) {
                this.clearTimer();
                this.resetPlayerSub.next({ success: true });
            }
        }), 1000);
    }
    /**
     * @return {?}
     */
    clearTimer() {
        if (this.resetPlayerTimer) {
            // clearTimeout(this.resetPlayerTimer);
            clearInterval(this.resetPlayerTimer);
            this.resetPlayerTimer = null;
        }
    }
    /**
     * @return {?}
     */
    resetPlayer() {
        return this.resetPlayerSub;
    }
}
NetworkDetectionService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
NetworkDetectionService.ctorParameters = () => [];
/** @nocollapse */ NetworkDetectionService.ngInjectableDef = ɵɵdefineInjectable({ factory: function NetworkDetectionService_Factory() { return new NetworkDetectionService(); }, token: NetworkDetectionService, providedIn: "root" });
if (false) {
    /**
     * @type {?}
     * @private
     */
    NetworkDetectionService.prototype.offlineSubscription;
    /**
     * @type {?}
     * @private
     */
    NetworkDetectionService.prototype.onlineSubscription;
    /**
     * @type {?}
     * @private
     */
    NetworkDetectionService.prototype.currentState;
    /**
     * @type {?}
     * @private
     */
    NetworkDetectionService.prototype.stateChangeEventEmitter;
    /** @type {?} */
    NetworkDetectionService.prototype.resetPlayerTimer;
    /**
     * @type {?}
     * @private
     */
    NetworkDetectionService.prototype.resetPlayerSub;
}
/**
 * Instance of this interface is used to report current connection status.
 * @record
 */
function ConnectionState() { }
if (false) {
    /**
     * "True" if browser has network connection. Determined by Window objects "online" / "offline" events.
     * @type {?}
     */
    ConnectionState.prototype.hasNetworkConnection;
    /**
     * "True" if browser has Internet access. Determined by heartbeat system which periodically makes request to heartbeat Url.
     * @type {?}
     */
    ConnectionState.prototype.hasInternetAccess;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/penpencil-player.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PenpencilPlayerComponent {
    /**
     * @param {?} networkDetectionService
     */
    constructor(networkDetectionService) {
        this.networkDetectionService = networkDetectionService;
        this.inIt = new EventEmitter();
        this.onPlay = new EventEmitter();
        this.onPause = new EventEmitter();
        this.onEnded = new EventEmitter();
        this.onError = new EventEmitter();
        this.onFullscreenchange = new EventEmitter();
        this.onVideoSkip = new EventEmitter();
        this.MAX_RETRY = 50;
        this.RETRY = 0;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    check(event) {
        console.log(event);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.playerConfigData = new PlayerConfig(this.playerConfig);
        this.callBacks();
        this.networkChange();
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() { }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        this.play(this.playerConfig);
    }
    /**
     * @private
     * @param {?} playerConfig
     * @return {?}
     */
    play(playerConfig) {
        this.playerConfigData = new PlayerConfig(playerConfig);
        this.playerInit();
        // if (this.player) {
        //   this.player.src(this.playerConfigData.sources);
        //   this.player.poster(this.playerConfigData.poster);
        // }
    }
    /**
     * @private
     * @return {?}
     */
    playerInit() {
        if (!this.playerConfigData.sources ||
            !this.playerConfigData.sources.length ||
            !this.playerConfigData.sources[0].src) {
            return;
        }
        this.setupPlayerControls();
        this.setupPlayer();
        this.setupSrc();
        this.initializePlugins();
    }
    /**
     * @private
     * @return {?}
     */
    setupPlayerControls() {
        if (this.playerConfigData.liveui) {
            this.playerControls = {
                playToggle: {},
                currentTimeDisplay: {},
                progressControl: {},
                liveui: {},
                fullscreenToggle: {},
                volumePanel: {
                    inline: false,
                    volumeControl: {
                        vertical: true
                    }
                }
            };
        }
        else {
            this.playerControls = {
                playToggle: {},
                currentTimeDisplay: {},
                progressControl: {},
                durationDisplay: {},
                fullscreenToggle: {},
                volumePanel: {
                    inline: false,
                    volumeControl: {
                        vertical: true
                    }
                }
            };
        }
    }
    /**
     * @private
     * @return {?}
     */
    setupPlayer() {
        this.player = videojs("rs_penpencil_player", {
            html5: {
                vhs: {
                    overrideNative: true,
                    experimentalLLHLS: this.playerConfigData.liveui && this.playerConfigData.forceLLHLSenable,
                    // in case of live && to enable LLHLS set it true
                    enableLowInitialPlaylist: this.playerConfigData.liveui,
                    // in case of live set it true
                    limitRenditionByPlayerDimensions: !this.playerConfigData.liveui,
                    // in case of live set it false dont pick quality by screen size just pick the lowest quality
                    // fastQualityChange: false,
                    experimentalBufferBasedABR: this.playerConfigData.liveui && this.playerConfigData.forceLLHLSenable,
                    bandwidth: this.playerConfigData.liveui ? 511023 : 1141986,
                    // in case of live video pick lowest bitrate video (< 0.5Mbps) else pick mid qualiry video (> 1Mbps)
                    hlsjsConfig: {
                        startLevel: 0,
                        capLevelToPlayerSize: false,
                        // startQuality: 106,
                        // blacklistDuration: 120,
                        enableWorker: true,
                        liveBackBufferLength: 15,
                        backBufferLength: 15,
                        liveMaxBackBufferLength: 15,
                        maxBufferSize: 0,
                        maxBufferLength: 10,
                        liveSyncDurationCount: 1
                    }
                },
                // hls: {
                //   overrideNative: true,
                //   enableLowInitialPlaylist: false
                // },
                nativeAudioTracks: false,
                nativeTextTracks: false
            },
            plugins: {
                eme: {},
                hotkeys: {
                    volumeStep: 0.2,
                    seekStep: this.playerConfigData.seekSeconds,
                    enableModifiersForNumbers: false
                }
            },
            poster: this.playerConfigData.poster,
            fill: this.playerConfigData.fill,
            fluid: this.playerConfigData.fluid,
            responsive: this.playerConfigData.responsive,
            playbackRates: [0.5, 1, 1.25, 1.5, 1.75, 2],
            controlBar: {
                children: this.playerControls
            },
            inactivityTimeout: 5000,
            preload: "metadata",
            controls: true,
            liveui: !!this.playerConfigData.liveui,
            autoplay: this.playerConfigData.autoplay,
            // currentTimeDisplay: true,
            errorDisplay: true,
            loadingSpinner: true,
            bigPlayButton: true,
            youtube: {
                ytControls: 0,
                enablePrivacyEnhancedMode: true
            }
        });
    }
    /**
     * @private
     * @return {?}
     */
    setupSrc() {
        this.player.src(this.playerConfig.sources);
        this.inIt.emit(this.player);
    }
    /**
     * @private
     * @return {?}
     */
    initializePlugins() {
        this.player.settingMenu({
            menu: ["speed", "quality"],
            defaultQuality: this.playerConfig.defaultQuality
        });
        this.player.bigPlayButton.hide();
        if (this.playerConfigData.seekButtons) {
            this.player.seekButtons({
                forward: {
                    direction: "forward",
                    seconds: this.playerConfigData.seekSeconds
                },
                backward: {
                    direction: "backward",
                    seconds: this.playerConfigData.seekSeconds
                }
            });
        }
        if (this.playerConfigData.watermark &&
            (this.playerConfigData.watermark.text ||
                this.playerConfigData.watermark.imageUrl)) {
            this.player.watermark(this.playerConfigData.watermark);
        }
    }
    /**
     * @return {?}
     */
    retryInitPlayer() {
        if (this.RETRY === this.MAX_RETRY) {
            this.player.errorDisplay = true;
            console.log("Maximum Reached  retry");
            return;
        }
        console.log("RETRY" + this.RETRY);
        this.player.error(null);
        setTimeout((/**
         * @return {?}
         */
        () => {
            this.play(this.playerConfig);
            this.RETRY++;
        }), 500);
    }
    /**
     * @private
     * @return {?}
     */
    callBacks() {
        if (this.playerConfigData.fullScreenEnabled) {
            this.player.requestFullscreen();
        }
        // this.player.on('error', (_, error) => {
        //   console.log('error: ', _, error);
        // });
        this.player.on('timeupdate', (/**
         * @return {?}
         */
        () => {
            this.previousTime = this.currentTime;
            this.currentTime = this.player.currentTime();
            console.log('timeupdate');
        }));
        this.player.on('seeking', (/**
         * @return {?}
         */
        () => {
            console.log('seeking');
            if (this.seekStart === null) {
                this.seekStart = this.previousTime;
            }
        }));
        this.player.on("seeked", (/**
         * @return {?}
         */
        () => {
            /** @type {?} */
            const data = {
                remainingTime: this.player.remainingTime(),
                currentTime: this.player.currentTime(),
                startTime: this.seekStart
            };
            console.log(data);
            this.seekStart = null;
            this.onVideoSkip.emit(data);
        }));
        this.player.on("error", (/**
         * @param {?} error
         * @return {?}
         */
        error => {
            this.onError.emit(error);
            // this.player.preventDefault();
            this.retryInitPlayer();
            console.log("error: ", error);
        }));
        this.player.on("changePlaybackRate", (/**
         * @param {?} _
         * @param {?} speed
         * @return {?}
         */
        (_, speed) => {
            this.playerConfigData.lastPlaybackRate = speed.item;
            if (this.networkDetectionService.resetPlayerTimer) {
                this.setResetPlayer(speed.item);
            }
        }));
        this.player.on("skip", (/**
         * @return {?}
         */
        () => {
            console.log("running");
        }));
        this.player.on("play", (/**
         * @return {?}
         */
        () => {
            /** @type {?} */
            const networkState = this.player.networkState();
            /** @type {?} */
            const readyState = this.player.readyState();
            /** @type {?} */
            const seeking = this.player.seeking();
            /** @type {?} */
            const currentTime = Math.round(this.player.currentTime());
            if (this.playerConfigData.startTime > 0 &&
                currentTime !== this.playerConfigData.startTime &&
                this.playerConfigData.startTime > currentTime &&
                !seeking) {
                this.playerConfigData.startTime = Math.round(this.playerConfigData.startTime);
                this.setCurrentTime(this.playerConfigData.startTime);
            }
            // console.log('this.playerConfigData: ', this.playerConfigData)
            this.setPlaybackRate(this.playerConfigData.lastPlaybackRate);
            this.onPlay.emit(this.getPlayerInfo());
            // console.log('networkState: ', networkState);
            // console.log('readyState: ', readyState);
            // console.log('seeking: ', seeking);
            // console.log('this.networkDetectionService.resetPlayerTimer: ', this.networkDetectionService.resetPlayerTimer);
            if (seeking && this.networkDetectionService.resetPlayerTimer) {
                this.setResetPlayer();
            }
        }));
        // this.player.on('timeupdate', (_, timeupdate) => {
        //   console.log('timeupdate: ', _, timeupdate);
        // });
        // videojs.on(this.player, 'timeupdate', (data) => {
        //   console.log('timeupdate: ', data);
        // });
        this.player.on("pause", (/**
         * @return {?}
         */
        () => {
            this.onPause.emit(this.getPlayerInfo());
        }));
        this.player.on("ready", (/**
         * @return {?}
         */
        () => {
            this.player.play();
            this.player.bigPlayButton.show();
            console.log("ready", this.player.ready());
            // this.player.tech().on('usage', (e) => {
            //   console.log('usage', e.name);
            // });
        }));
        this.player.on("ended", (/**
         * @return {?}
         */
        () => {
            this.onEnded.emit(this.getPlayerInfo());
        }));
        this.player.on("fullscreenchange", (/**
         * @return {?}
         */
        () => {
            this.onFullscreenchange.emit(this.getPlayerInfo());
        }));
        // if (this.playerConfigData.sources && this.playerConfigData.sources.length && this.playerConfigData.sources[0].type === 'application/x-mpegURL') {
        this.player.on("loadstart", (/**
         * @param {?} e
         * @return {?}
         */
        e => {
            /** @type {?} */
            const vhs = this.player.tech().hls;
            if (vhs) {
                vhs.xhr.beforeRequest = (/**
                 * @param {?} options
                 * @return {?}
                 */
                options => {
                    // console.log('this.player.tech()', this.player.tech().hls.bandwidth, this.formatBytes(this.player.tech().hls.bandwidth));
                    if (this.playerConfigData.query) {
                        /** @type {?} */
                        let URI = options.uri;
                        if (this.playerConfigData.query[0] !== "?") {
                            this.playerConfigData.query = "?" + this.playerConfigData.query;
                        }
                        if (URI.split("?").length > 1) {
                            URI =
                                URI.split("?")[0] +
                                    this.playerConfigData.query +
                                    "&" +
                                    URI.split("?")[1];
                        }
                        if (URI.includes("v1/videos/get-hls-key?videoKey=")) {
                            /** @type {?} */
                            const videoUrl = this.playerConfigData.sources[0].src;
                            /** @type {?} */
                            const videoUrlArr = videoUrl.split("?")[0].split("/");
                            /** @type {?} */
                            const videoHost = videoUrlArr.slice(0, 3).join("/") + "/";
                            /** @type {?} */
                            const videoKey = videoUrlArr.slice(3).join("/");
                            // console.log('options.uri', options.uri, videoHost, videoKey.replace('master.m3u8', '/hls/enc.key'));
                            URI = videoHost + videoKey.replace("master.m3u8", "hls/enc.key");
                        }
                        if (URI.includes("v1/videos/get-hls-key")) {
                            /** @type {?} */
                            let query = URI.split('?')[1];
                            if (query.length > 0) {
                                URI = URI + `&authorization=${this.playerConfigData.accessToken}`;
                            }
                            else {
                                URI = URI + `?authorization=${this.playerConfigData.accessToken}`;
                            }
                        }
                        // console.log('policy check');
                        if (!URI.includes("Policy") &&
                            !URI.includes("Policy") &&
                            !URI.includes("Policy")) {
                            URI = options.uri + this.playerConfigData.query;
                        }
                        options.uri = URI;
                    }
                    if (this.playerConfigData.encryptionUri) {
                        if (options.uri.includes("key://") &&
                            this.playerConfigData.encryptionUri) {
                            /** @type {?} */
                            const key = options.uri.replace("key://", "");
                            options.uri = this.playerConfigData.encryptionUri + "&key=" + key;
                            if (this.playerConfigData.headers &&
                                this.playerConfigData.headers.length) {
                                /** @type {?} */
                                const headers = options.headers || {};
                                for (let i = 0; i < this.playerConfigData.headers.length; i++) {
                                    Object.assign(headers, this.playerConfigData.headers[i]);
                                }
                                options.headers = headers;
                            }
                        }
                    }
                    // else {
                    //   console.log('VHS does not exist', this.player);
                    // }
                });
            }
        }));
        // }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        // call this method in ngDestroy - basically this method will remove the player
        this.player.dispose();
    }
    // set current time in seconds
    /**
     * @private
     * @param {?} time
     * @return {?}
     */
    setCurrentTime(time) {
        this.player.currentTime(time);
    }
    /**
     * @private
     * @param {?} lastPlaybackrate
     * @return {?}
     */
    setPlaybackRate(lastPlaybackrate) {
        this.player.playbackRate(lastPlaybackrate);
    }
    /**
     * @private
     * @return {?}
     */
    getPlayerInfo() {
        this.playerInfo = new PlayerInfo();
        this.playerInfo.play = !this.player.paused();
        this.playerInfo.pause = this.player.paused();
        this.playerInfo.ended = this.player.ended();
        this.playerInfo.poster = this.player.poster();
        // this.playerInfo.sources = this.playerConfig.sources;
        // this.playerInfo.type = this.playerConfig.type;
        this.playerInfo.duration = this.player.duration();
        this.playerInfo.volume = this.player.volume();
        this.playerInfo.playTime = this.player.currentTime();
        this.playerInfo.remainingTime = this.player.remainingTime();
        this.playerInfo.muted = this.player.muted();
        this.playerInfo.fullScreen = this.player.isFullscreen();
        return this.playerInfo;
    }
    /**
     * @return {?}
     */
    networkChange() {
        if (this.networkDetectionSubs) {
            this.networkDetectionSubs.unsubscribe();
        }
        if (this.playerResetSubs) {
            this.playerResetSubs.unsubscribe();
        }
        this.networkDetectionSubs = this.networkDetectionService
            .monitor(false)
            .subscribe((/**
         * @param {?} currentState
         * @return {?}
         */
        currentState => {
            /** @type {?} */
            const hasNetworkConnection = currentState.hasNetworkConnection;
            /** @type {?} */
            const hasInternetAccess = currentState.hasInternetAccess;
            if (hasNetworkConnection && hasInternetAccess) {
                this.setResetPlayer();
            }
            // else {
            // this.player.trigger('error', {});
            // const playerBuffered = this.player.bufferedEnd();
            //
            // const pauseAfter = (Math.round(playerBuffered) - currentPlayerInfo.playTime) * 1000 || 0;
            // // console.log('pauseAfter: ', playerBuffered, currentPlayerInfo.playTime, pauseAfter);
            // setTimeout( () => {
            //   this.player.pause();
            // }, pauseAfter);
            // }
        }));
        this.playerResetSubs = this.networkDetectionService
            .resetPlayer()
            .subscribe((/**
         * @param {?} value
         * @return {?}
         */
        value => {
            if (value) {
                this.resetPlayer();
            }
        }));
    }
    /**
     * @param {?} bytes
     * @param {?=} decimals
     * @return {?}
     */
    formatBytes(bytes, decimals = 2) {
        if (bytes === 0)
            return "0 Bytes";
        /** @type {?} */
        const k = 1024;
        /** @type {?} */
        const dm = decimals < 0 ? 0 : decimals;
        /** @type {?} */
        const sizes = ["Bytes", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB"];
        /** @type {?} */
        const i = Math.floor(Math.log(bytes) / Math.log(k));
        return parseFloat((bytes / Math.pow(k, i)).toFixed(dm)) + " " + sizes[i];
    }
    /**
     * @param {?=} playbackRate
     * @return {?}
     */
    setResetPlayer(playbackRate) {
        /** @type {?} */
        const lastPlaybackRate = playbackRate || this.player.playbackRate();
        /** @type {?} */
        const playerBuffered = Math.round(this.player.bufferedEnd());
        /** @type {?} */
        const currentTime = Math.round(this.player.currentTime());
        /** @type {?} */
        let resetAfter = (playerBuffered - currentTime) * 1000 || 0;
        // console.log(currentTime, playerBuffered, resetAfter);
        if (!resetAfter) {
            resetAfter = 1000;
        }
        /** @type {?} */
        const data = {
            resetAfter,
            lastPlaybackRate: lastPlaybackRate * 1000
        };
        // console.log('data: ', data);
        this.networkDetectionService.setResetPlayer(data);
    }
    /**
     * @return {?}
     */
    resetPlayer() {
        /** @type {?} */
        const lastPlaybackRate = this.player.playbackRate();
        /** @type {?} */
        const playerConfigTemp = Object.assign({}, this.playerConfig);
        playerConfigTemp.startTime = Math.round(this.player.currentTime());
        playerConfigTemp.lastPlaybackRate = lastPlaybackRate;
        this.playerConfigData = playerConfigTemp;
        // console.log('this.playerConfig: ', this.playerConfig.startTime);
        // this.player.reset();
        this.player.src(playerConfigTemp.sources);
        // this.play(playerConfigTemp);
        if (!playerConfigTemp.autoplay) {
            setTimeout((/**
             * @return {?}
             */
            () => {
                this.player.play();
            }), 500);
        }
    }
}
PenpencilPlayerComponent.decorators = [
    { type: Component, args: [{
                selector: "rs-penpencil-player",
                template: "<video controls id=\"rs_penpencil_player\" autofocus class=\"video-js video-js-default vjs-theme-city vjs-matrix vjs-16-9\"\n           data-setup='{}'>\n  <!--<source src=\"{{url1}}\" type='video/mp4' label='SD' res='360' />-->\n  <!--<source src=\"{{url2}}\" type='video/mp4' label='HD' res='720'/>-->\n    <p class=\"vjs-no-js\">To view this video please enable JavaScript, and consider upgrading to a web browser that <a href=\"http://videojs.com/html5-video-support/\" target=\"_blank\">supports HTML5 video</a></p>\n</video>\n",
                encapsulation: ViewEncapsulation.None,
                styles: [".video-js{color:#555}.vjs-liveui-display .vjs-control-text{display:none!important}@media screen and (max-width:425px){.vjs-theme-city .vjs-control-bar .vjs-current-time,.vjs-theme-city .vjs-control-bar .vjs-duration{font-size:10px!important;top:-50px}.vjs-theme-city .vjs-control-bar .vjs-progress-control{font-size:16px!important;top:-16px}}.vjs-theme-city{--vjs-theme-city--primary:#bf3b4d;--vjs-theme-city--secondary:#fff;--vjs-theme-city--icon-color:#555555;--vjs-theme-city--size:2em}.vjs-theme-city .vjs-big-play-button{font-size:2.5em;line-height:2em;height:2em;width:2em;background-color:var(--vjs-theme-city--primary);color:var(--vjs-theme-city--secondary);border-radius:1em;left:50%;top:50%;margin-left:-1em;margin-top:-1em}.vjs-theme-city .vjs-loading-spinner{border:3px solid #2b333f!important}.vjs-theme-city .vjs-loading-spinner::after,.vjs-theme-city .vjs-loading-spinner::before{border-color:var(--vjs-theme-city--primary);margin:-3px}.vjs-theme-city .vjs-control{outline:0}.vjs-theme-city .vjs-setting-home{background-color:rgba(255,255,255,.66);position:absolute;right:10%;border-radius:5px;font-size:1.8em;height:auto;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;bottom:45px}.vjs-theme-city .vjs-control-bar{background-color:transparent;bottom:.7em;height:40px;left:0;position:absolute;right:0;width:98%;margin:auto;border-radius:5px;font-weight:700}.vjs-theme-city .vjs-control-bar .vjs-current-time,.vjs-theme-city .vjs-control-bar .vjs-duration{display:flex;position:relative;top:-60px;font-size:20px;font-weight:500;line-height:40px;text-align:center;padding:0;margin:0}.vjs-theme-city .vjs-control-bar .vjs-current-time-display{left:-100px;position:relative}.vjs-theme-city .vjs-control-bar .vjs-liveui{line-height:4em}.vjs-theme-city .vjs-control-bar .vjs-liveui .vjs-liveui-display:before{content:\"\";position:absolute;bottom:18px;left:0;width:5px;height:5px;background-color:var(--vjs-theme-city--primary);border-radius:50%}.vjs-theme-city .vjs-control-bar .vjs-button>.vjs-icon-placeholder::before,.vjs-theme-city .vjs-control-bar .vjs-playback-rate .vjs-playback-rate-value{display:flex;font-size:2.5em;line-height:1.2em;justify-content:center;align-items:center;align-content:center}.vjs-theme-city .vjs-control-bar .vjs-icon-cog:before,.vjs-theme-city .vjs-control-bar .vjs-icon-replay:before{font-size:2.5em}.vjs-theme-city .vjs-control-bar .vjs-setting-menu-button{transition:transform .3s;transform:rotate(0);position:absolute;right:90px}@media (max-width:1024px){.vjs-theme-city .vjs-control-bar .vjs-setting-menu-button{right:90px}}@media (max-width:768px){.vjs-theme-city .vjs-control-bar .vjs-setting-menu-button{right:85px}}@media (max-width:540px){.vjs-theme-city .vjs-control-bar .vjs-setting-menu-button{right:90px}}.vjs-theme-city .vjs-control-bar .vjs-setting-button-anim{transform:rotate(90deg)}.vjs-theme-city .vjs-control-bar .vjs-progress-control{font-size:3em}.vjs-theme-city .vjs-control-bar .vjs-progress-control .vjs-load-progress,.vjs-theme-city .vjs-control-bar .vjs-progress-control .vjs-play-progress,.vjs-theme-city .vjs-control-bar .vjs-progress-control .vjs-progress-holder{border-radius:25px}.vjs-theme-city .vjs-control-bar .vjs-progress-control .vjs-play-progress{background-color:#5156cf}.vjs-theme-city .vjs-control-bar .vjs-progress-control .vjs-play-progress::before{display:block;color:#7b80ff}.vjs-theme-city .vjs-control-bar .vjs-setting-menu-main{position:absolute;bottom:110%;right:0;background-color:rgba(255,255,255,.66);font-size:1.3em;border-radius:5px;transition:width .5s;padding:2px}.vjs-theme-city .vjs-control-bar .vjs-setting-menu-main .vjs-menu-content{background-color:#000;list-style:none;padding:0;margin:0}.vjs-theme-city .vjs-control-bar .vjs-setting-menu-main .vjs-menu-content .vjs-setting-item{padding:4px;display:flex;cursor:pointer;text-transform:capitalize;border-radius:5px;width:9em}.vjs-theme-city .vjs-control-bar .vjs-setting-menu-main .vjs-menu-content .vjs-setting-item span{margin:4px 6px;width:50%;display:block}.vjs-theme-city .vjs-control-bar .vjs-setting-menu-main .vjs-menu-content .vjs-setting-item .text-right{text-align:right}.vjs-theme-city .vjs-control-bar .vjs-setting-menu-main .vjs-menu-content .vjs-setting-item .text-left{text-align:left}.vjs-theme-city .vjs-control-bar .vjs-setting-menu-main .vjs-menu-content .vjs-setting-item .vjs-setting-icon{text-align:right}.vjs-theme-city .vjs-control-bar .vjs-setting-menu-main .vjs-menu-content .vjs-setting-item .vjs-icon-circle-inner-circle,.vjs-theme-city .vjs-control-bar .vjs-setting-menu-main .vjs-menu-content .vjs-setting-item .vjs-icon-circle-outline{font-size:1.3em}.vjs-theme-city .vjs-control-bar .vjs-setting-menu-main .vjs-menu-content .vjs-setting-item .vjs-icon-circle-inner-circle{color:#fff}.vjs-theme-city .vjs-control-bar .vjs-setting-menu-main .vjs-menu-content .vjs-setting-item-selected,.vjs-theme-city .vjs-control-bar .vjs-setting-menu-main .vjs-menu-content .vjs-setting-item:active,.vjs-theme-city .vjs-control-bar .vjs-setting-menu-main .vjs-menu-content .vjs-setting-item:focus,.vjs-theme-city .vjs-control-bar .vjs-setting-menu-main .vjs-menu-content .vjs-setting-item:hover{background-color:var(--vjs-theme-city--primary);color:#fff}.vjs-theme-city .vjs-control-bar .vjs-setting-menu-main .vjs-menu-content .vjs-setting-item-selected .vjs-icon-circle-inner-circle,.vjs-theme-city .vjs-control-bar .vjs-setting-menu-main .vjs-menu-content .vjs-setting-item:active .vjs-icon-circle-inner-circle,.vjs-theme-city .vjs-control-bar .vjs-setting-menu-main .vjs-menu-content .vjs-setting-item:focus .vjs-icon-circle-inner-circle,.vjs-theme-city .vjs-control-bar .vjs-setting-menu-main .vjs-menu-content .vjs-setting-item:hover .vjs-icon-circle-inner-circle{color:#fff}.video-js .vjs-title-bar{background:rgba(0,0,0,.5);color:#fff;display:none;font-size:2em;padding:.5em;position:absolute;top:0;left:0;width:100%}.vjs-control-bar{color:#fff}.vjs-play-control.vjs-play{content:\"projects/penpencil-player/src/assets/backward.svg\"}.vjs-seek-button.vjs-skip-forward{height:30px;width:27px;margin-top:5px}.vjs-seek-button.vjs-skip-backward{height:30px;margin-top:5px;width:27px;background-size:100%}.video-js.vjs-paused.vjs-has-started .vjs-title-bar,.video-js.vjs-user-active.vjs-has-started .vjs-title-bar{display:block}.vjs-theme-city .vjs-progress-control{position:absolute;top:-25px;right:0;left:0;width:100%;height:20px}.vjs-theme-city .vjs-remaining-time{order:1;line-height:50px;flex:3 1;text-align:left}.vjs-duration.vjs-time-control.vjs-control{position:absolute;right:0!important}.vjs-fullscreen-control.vjs-control.vjs-button{position:absolute;right:53px}.video-js .vjs-volume-panel.vjs-volume-panel-vertical{position:absolute;right:15px}"]
            }] }
];
/** @nocollapse */
PenpencilPlayerComponent.ctorParameters = () => [
    { type: NetworkDetectionService }
];
PenpencilPlayerComponent.propDecorators = {
    playerConfig: [{ type: Input }],
    inIt: [{ type: Output }],
    onPlay: [{ type: Output }],
    onPause: [{ type: Output }],
    onEnded: [{ type: Output }],
    onError: [{ type: Output }],
    onFullscreenchange: [{ type: Output }],
    onVideoSkip: [{ type: Output }]
};
if (false) {
    /** @type {?} */
    PenpencilPlayerComponent.prototype.playerConfig;
    /** @type {?} */
    PenpencilPlayerComponent.prototype.inIt;
    /** @type {?} */
    PenpencilPlayerComponent.prototype.onPlay;
    /** @type {?} */
    PenpencilPlayerComponent.prototype.onPause;
    /** @type {?} */
    PenpencilPlayerComponent.prototype.onEnded;
    /** @type {?} */
    PenpencilPlayerComponent.prototype.onError;
    /** @type {?} */
    PenpencilPlayerComponent.prototype.onFullscreenchange;
    /** @type {?} */
    PenpencilPlayerComponent.prototype.onVideoSkip;
    /**
     * @type {?}
     * @private
     */
    PenpencilPlayerComponent.prototype.player;
    /**
     * @type {?}
     * @private
     */
    PenpencilPlayerComponent.prototype.playerConfigData;
    /**
     * @type {?}
     * @private
     */
    PenpencilPlayerComponent.prototype.playerInfo;
    /**
     * @type {?}
     * @private
     */
    PenpencilPlayerComponent.prototype.playerControls;
    /**
     * @type {?}
     * @private
     */
    PenpencilPlayerComponent.prototype.networkDetectionSubs;
    /**
     * @type {?}
     * @private
     */
    PenpencilPlayerComponent.prototype.playerResetSubs;
    /**
     * @type {?}
     * @private
     */
    PenpencilPlayerComponent.prototype.MAX_RETRY;
    /**
     * @type {?}
     * @private
     */
    PenpencilPlayerComponent.prototype.RETRY;
    /**
     * @type {?}
     * @private
     */
    PenpencilPlayerComponent.prototype.previousTime;
    /**
     * @type {?}
     * @private
     */
    PenpencilPlayerComponent.prototype.currentTime;
    /**
     * @type {?}
     * @private
     */
    PenpencilPlayerComponent.prototype.seekStart;
    /**
     * @type {?}
     * @private
     */
    PenpencilPlayerComponent.prototype.networkDetectionService;
}
// WARNING: interface has both a type and a value, skipping emit
class PlayerInfo {
    /**
     * @param {?=} info
     */
    constructor(info) {
        /** @type {?} */
        const data = info || {};
        this.play = data.play || false;
        this.pause = data.pause || false;
        this.ended = data.ended || false;
        this.duration = Math.round(data.duration) || 0;
        this.poster = data.poster || "";
        this.volume = data.volume || 0;
        this.playTime = Math.round(data.playTime) || 0;
        this.remainingTime = Math.round(data.remainingTime) || 0;
        this.muted = data.muted || false;
        this.fullScreen = data.fullScreen || false;
    }
}
if (false) {
    /** @type {?} */
    PlayerInfo.prototype.play;
    /** @type {?} */
    PlayerInfo.prototype.pause;
    /** @type {?} */
    PlayerInfo.prototype.ended;
    /** @type {?} */
    PlayerInfo.prototype.duration;
    /** @type {?} */
    PlayerInfo.prototype.poster;
    /** @type {?} */
    PlayerInfo.prototype.volume;
    /** @type {?} */
    PlayerInfo.prototype.playTime;
    /** @type {?} */
    PlayerInfo.prototype.remainingTime;
    /** @type {?} */
    PlayerInfo.prototype.muted;
    /** @type {?} */
    PlayerInfo.prototype.fullScreen;
}
// WARNING: interface has both a type and a value, skipping emit
class PlayerConfig {
    /**
     * @param {?} config
     * @param {?=} playerCache
     */
    constructor(config, playerCache) {
        /** @type {?} */
        const data = config || {};
        this.accessToken = data.accessToken || '';
        this.forceLLHLSenable = data.forceLLHLSenable || false;
        this.poster = data.poster || "";
        this.liveui = data.liveui || false;
        this.sources = data.sources || [];
        this.type = data.type || "application/x-mpegURL";
        this.autoplay = data.autoplay || false;
        this.encryptionUri = data.encryptionUri || "";
        this.query = data.query || "";
        this.headers = data.headers || "";
        this.startTime = Math.round(data.startTime) || 0;
        this.fullScreenEnabled = data.fullScreenEnabled || false;
        this.fluid = data.fluid || false;
        this.fill = data.fill || false;
        this.responsive = data.responsive || false;
        this.defaultQuality = data.defaultQuality || "Auto";
        this.forwardBackward = data.forwardBackward || false;
        this.watermark = data.watermark || {};
        this.seekButtons = data.seekButtons || false;
        this.seekSeconds = data.seekSeconds || 10;
        this.lastPlaybackRate = data.lastPlaybackRate || 1;
    }
}
if (false) {
    /** @type {?} */
    PlayerConfig.prototype.accessToken;
    /** @type {?} */
    PlayerConfig.prototype.poster;
    /** @type {?} */
    PlayerConfig.prototype.liveui;
    /** @type {?} */
    PlayerConfig.prototype.forceLLHLSenable;
    /** @type {?} */
    PlayerConfig.prototype.sources;
    /** @type {?} */
    PlayerConfig.prototype.type;
    /** @type {?} */
    PlayerConfig.prototype.autoplay;
    /** @type {?} */
    PlayerConfig.prototype.encryptionUri;
    /** @type {?} */
    PlayerConfig.prototype.query;
    /** @type {?} */
    PlayerConfig.prototype.headers;
    /** @type {?} */
    PlayerConfig.prototype.startTime;
    /** @type {?} */
    PlayerConfig.prototype.fullScreenEnabled;
    /** @type {?} */
    PlayerConfig.prototype.fluid;
    /** @type {?} */
    PlayerConfig.prototype.fill;
    /** @type {?} */
    PlayerConfig.prototype.defaultQuality;
    /** @type {?} */
    PlayerConfig.prototype.responsive;
    /** @type {?} */
    PlayerConfig.prototype.forwardBackward;
    /** @type {?} */
    PlayerConfig.prototype.watermark;
    /** @type {?} */
    PlayerConfig.prototype.seekButtons;
    /** @type {?} */
    PlayerConfig.prototype.seekSeconds;
    /** @type {?} */
    PlayerConfig.prototype.lastPlaybackRate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/penpencil-player.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PenpencilPlayerModule {
}
PenpencilPlayerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [PenpencilPlayerComponent],
                imports: [],
                exports: [PenpencilPlayerComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: penpencil-player.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { PenpencilPlayerComponent, PenpencilPlayerModule, NetworkDetectionService as ɵa };
//# sourceMappingURL=penpencil-player.js.map
